package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.OrderSoundMapper;
import com.ruoyi.system.domain.OrderSound;
import com.ruoyi.system.service.IOrderSoundService;

/**
 * 服务订单录音文件Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class OrderSoundServiceImpl implements IOrderSoundService 
{
    @Autowired
    private OrderSoundMapper orderSoundMapper;

    /**
     * 查询服务订单录音文件
     * 
     * @param id 服务订单录音文件主键
     * @return 服务订单录音文件
     */
    @Override
    public OrderSound selectOrderSoundById(Integer id)
    {
        return orderSoundMapper.selectOrderSoundById(id);
    }


    public int  selectCountOrderSoundByOid(long oid){
        return orderSoundMapper.selectCountOrderSoundByOid(oid);
    }



    public List<OrderSound>  selectOrderSoundByOid(long oid) {
        return orderSoundMapper.selectOrderSoundByOid(oid);
    }


    @Override
    public List<OrderSound> selectOrderCallRecordsByOid(Long oid)
    {
        return orderSoundMapper.selectOrderCallRecordsByOid(oid);
    }

    /**
     * 查询服务订单录音文件列表
     * 
     * @param orderSound 服务订单录音文件
     * @return 服务订单录音文件
     */
    @Override
    public List<OrderSound> selectOrderSoundList(OrderSound orderSound)
    {
        return orderSoundMapper.selectOrderSoundList(orderSound);
    }

    /**
     * 新增服务订单录音文件
     * 
     * @param orderSound 服务订单录音文件
     * @return 结果
     */
    @Override
    public int insertOrderSound(OrderSound orderSound)
    {
        return orderSoundMapper.insertOrderSound(orderSound);
    }

    /**
     * 修改服务订单录音文件
     * 
     * @param orderSound 服务订单录音文件
     * @return 结果
     */
    @Override
    public int updateOrderSound(OrderSound orderSound)
    {
        return orderSoundMapper.updateOrderSound(orderSound);
    }

    /**
     * 批量删除服务订单录音文件
     * 
     * @param ids 需要删除的服务订单录音文件主键
     * @return 结果
     */
    @Override
    public int deleteOrderSoundByIds(Integer[] ids)
    {
        return orderSoundMapper.deleteOrderSoundByIds(ids);
    }

    /**
     * 删除服务订单录音文件信息
     * 
     * @param id 服务订单录音文件主键
     * @return 结果
     */
    @Override
    public int deleteOrderSoundById(Integer id)
    {
        return orderSoundMapper.deleteOrderSoundById(id);
    }
}
